@@ -2,12 +2,12 @@
 // Program to pull the information out of various types of EXIF digital 
 // camera files and show it in a reasonably consistent way
 //
-// Version 2.8
+// Version 2.82
 //
 // Compiling under Windows:  
 //   Make sure you have Microsoft's compiler on the path, then run make.bat
 //
-// Dec 1999 - Nov 2007
+// Dec 1999 - Apr 2008
 //
 // by Matthias Wandel   www.sentex.net/~mwandel
 //--------------------------------------------------------------------------
@@ -15,7 +15,7 @@
 
 #include <sys/stat.h>
 
-#define JHEAD_VERSION "2.8"
+#define JHEAD_VERSION "2.82"
 
 // This #define turns on features that are too very specific to 
 // how I organize my photos.  Best to ignore everything inside #ifdef MATTHIAS
@@ -59,6 +59,7 @@ static unsigned FileTimeToExif = FALSE;
 static int DeleteComments = FALSE;
 static int DeleteExif = FALSE;
 static int DeleteIptc = FALSE;
+static int DeleteXmp = FALSE;
 static int DeleteUnknown = FALSE;
 static char * ThumbSaveName = NULL; // If not NULL, use this string to make up
                                     // the filename to store the thumbnail to.
@@ -870,7 +871,7 @@ void ProcessFile(const char * FileName)
                    EditComment || CommentInsertfileName || CommentInsertLiteral){
 
         Section_t * CommentSec;
-        char Comment[1001];
+        char Comment[MAX_COMMENT_SIZE+1];
         int CommentSize;
 
         CommentSec = FindSection(M_COM);
@@ -886,9 +887,9 @@ void ProcessFile(const char * FileName)
         }
 
         CommentSize = CommentSec->Size-2;
-        if (CommentSize > 1000){
-            fprintf(stderr, "Truncating comment at 1000 chars\n");
-            CommentSize = 1000;
+        if (CommentSize > MAX_COMMENT_SIZE){
+            fprintf(stderr, "Truncating comment at %d chars\n",MAX_COMMENT_SIZE);
+            CommentSize = MAX_COMMENT_SIZE;
         }
 
         if (CommentInsertfileName){
@@ -910,11 +911,11 @@ void ProcessFile(const char * FileName)
                 if (CommentSize < 0) CommentSize = 0;
             }
         }else if (CommentInsertLiteral){
-            strncpy(Comment, CommentInsertLiteral, 1000);
+            strncpy(Comment, CommentInsertLiteral, MAX_COMMENT_SIZE);
             CommentSize = strlen(Comment);
         }else{
 #ifdef MATTHIAS
-            char CommentZt[1001];
+            char CommentZt[MAX_COMMENT_SIZE+1];
             memcpy(CommentZt, (char *)CommentSec->Data+2, CommentSize);
             CommentZt[CommentSize] = '\0';
             if (ModifyDescriptComment(Comment, CommentZt)){
@@ -1040,6 +1041,9 @@ skip_unixtime:
     if (DeleteIptc){
         if (RemoveSectionType(M_IPTC)) Modified = TRUE;
     }
+    if (DeleteXmp){
+        if (RemoveSectionType(M_XMP)) Modified = TRUE;
+    }
     if (DeleteUnknown){
         if (RemoveUnknownSections()) Modified = TRUE;
     }
@@ -1126,7 +1130,7 @@ badtime:
 static void Usage (void)
 {
     printf("Jhead is a program for manipulating settings and thumnails in Exif jpeg headers\n"
-           "used by most Digital Cameras.  v"JHEAD_VERSION" Matthias Wandel, Nov 13 2007.\n"
+           "used by most Digital Cameras.  v"JHEAD_VERSION" Matthias Wandel, Apr 03 2008.\n"
            "http://www.sentex.net/~mwandel/jhead\n"
            "\n");
 
@@ -1141,6 +1145,7 @@ static void Usage (void)
            "  -dc        Delete comment field (as left by progs like Photoshop & Compupic)\n"
            "  -de        Strip Exif section (smaller JPEG file, but lose digicam info)\n"
            "  -di        Delete IPTC section (from Photoshop, or Picasa)\n"
+           "  -dx        Deletex XMP section\n"
            "  -du        Delete non image sections except for Exif and comment sections\n"
            "  -purejpg   Strip all unnecessary data from jpeg (combines -dc -de and -du)\n"
            "  -mkexif    Create new minimal exif section (overwrites pre-existing exif)\n"
@@ -1332,6 +1337,9 @@ int main (int argc, char **argv)
         }else if (!strcmp(arg,"-di")){
             DeleteIptc = TRUE;
             DoModify = TRUE;
+        }else if (!strcmp(arg,"-dx")){
+            DeleteXmp = TRUE;
+            DoModify = TRUE;
         }else if (!strcmp(arg, "-du")){
             DeleteUnknown = TRUE;
             DoModify = TRUE;
