@@ -35,7 +35,7 @@ typedef unsigned char uchar;
     #define FALSE 0
 #endif
 
-#define MAX_COMMENT 2000
+#define MAX_COMMENT_SIZE 2000
 
 #ifdef _WIN32
     #define PATH_MAX _MAX_PATH
@@ -86,7 +86,7 @@ typedef struct {
     int   ISOequivalent;
     int   LightSource;
     int   DistanceRange;
-    char  Comments[MAX_COMMENT];
+    char  Comments[MAX_COMMENT_SIZE];
 
     unsigned ThumbnailOffset;          // Exif offset to thumbnail
     unsigned ThumbnailSize;            // Size of thumbnail.
@@ -166,7 +166,8 @@ void ProcessGpsInfo(unsigned char * ValuePtr, int ByteCount,
                 unsigned char * OffsetBase, unsigned ExifLength);
 
 // iptc.c prototpyes
-void    show_IPTC (unsigned char * CharBuf, unsigned int length);
+void show_IPTC (unsigned char * CharBuf, unsigned int length);
+void ShowXmp(Section_t XmpSection);
 
 // Prototypes for myglob.c module
 extern void MyGlob(const char * Pattern , void (*FileFuncParm)(const char * FileName));
@@ -196,11 +197,11 @@ extern int ShowTags;
 // in this program.  (See jdmarker.c for a more complete list.)
 //--------------------------------------------------------------------------
 
-#define M_SOF0  0xC0            // Start Of Frame N
-#define M_SOF1  0xC1            // N indicates which compression process
-#define M_SOF2  0xC2            // Only SOF0-SOF2 are now in common use
+#define M_SOF0  0xC0          // Start Of Frame N
+#define M_SOF1  0xC1          // N indicates which compression process
+#define M_SOF2  0xC2          // Only SOF0-SOF2 are now in common use
 #define M_SOF3  0xC3
-#define M_SOF5  0xC5            // NB: codes C4 and CC are NOT SOF markers
+#define M_SOF5  0xC5          // NB: codes C4 and CC are NOT SOF markers
 #define M_SOF6  0xC6
 #define M_SOF7  0xC7
 #define M_SOF9  0xC9
@@ -209,13 +210,14 @@ extern int ShowTags;
 #define M_SOF13 0xCD
 #define M_SOF14 0xCE
 #define M_SOF15 0xCF
-#define M_SOI   0xD8            // Start Of Image (beginning of datastream)
-#define M_EOI   0xD9            // End Of Image (end of datastream)
-#define M_SOS   0xDA            // Start Of Scan (begins compressed data)
-#define M_JFIF  0xE0            // Jfif marker
-#define M_EXIF  0xE1            // Exif marker
-#define M_COM   0xFE            // COMment 
+#define M_SOI   0xD8          // Start Of Image (beginning of datastream)
+#define M_EOI   0xD9          // End Of Image (end of datastream)
+#define M_SOS   0xDA          // Start Of Scan (begins compressed data)
+#define M_JFIF  0xE0          // Jfif marker
+#define M_EXIF  0xE1          // Exif marker.  Also used for XMP data!
+#define M_XMP   0x10E1        // Not a real tag (same value in file as Exif!)
+#define M_COM   0xFE          // COMment 
 #define M_DQT   0xDB
 #define M_DHT   0xC4
 #define M_DRI   0xDD
-#define M_IPTC  0xED            // IPTC marker
+#define M_IPTC  0xED          // IPTC marker
